@@ -2,6 +2,7 @@
 
 #Import numpy
 import numpy as np
+from functools import reduce
 
 def empty_list(length, dimensions=1):
     """Create an empty list with specified length and dimensions.
@@ -46,4 +47,15 @@ def list_total(l):
     try:
         return float(sum(flatten_list(l)))
     except TypeError:
-        return 0
\ No newline at end of file
+        return 0
+
+def hamming_error_position(bits):
+    """Gets the errored bit in a hamming code.
+
+    Parameters:
+    bits (list): A list of bits.
+
+    Returns:
+    int: The index of an errored bit
+    """
+    return reduce(lambda x, y: x ^ y, [i for i, bit in enumerate(bits) if bit])
